// Copyright (c) 2009 Olivier Crave
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef GLMDICHILD_H
#define GLMDICHILD_H

#include "glwidget.h"
#include "stlfile.h"

class GLMdiChild : public GLWidget {

  Q_OBJECT

 public:
  GLMdiChild(QWidget *parent = 0);
  ~GLMdiChild();
  void newFile();
  bool loadFile(const QString &fileName);
  bool save();
  bool saveAs();
  bool saveFile(const QString &fileName);
  bool saveImage();
  QString userFriendlyCurrentFile();
  QString currentFile() { return curFile; };
  StlFile::Stats getStats() const { return stlFile->getStats(); };
  bool isUntitled;

 signals:
  void mouseButtonPressed(Qt::MouseButtons button);
  void mouseButtonReleased(Qt::MouseButtons button);

 protected:
  void closeEvent(QCloseEvent *event);
  void mousePressEvent(QMouseEvent *event);
  void mouseReleaseEvent(QMouseEvent *event);

 private:
  bool maybeSave();
  void setCurrentFile(const QString &fileName);
  QString strippedName(const QString &fullFileName);
  StlFile *stlFile;
  QString curFile;
};

#endif  // GLMDICHILD_H
